@@ -1,11 +1,11 @@
 from __future__ import annotations
 
+import logging
 import os
 import pathlib
 import random
-import logging
 from enum import Enum, auto
-from typing import Iterable, Union
+from typing import Iterable
 from urllib import request
 from urllib.error import HTTPError
 
@@ -16,12 +16,12 @@ class Verification():
     """
     Verification is a helper object for storing errors generated
     when creating a markdown document. This object is largely used
-    internally to verify the contents of a document, but can be 
-    accessed through the various verify() methods throughout the 
-    library by the user. A convenience method is provided in Document 
+    internally to verify the contents of a document, but can be
+    accessed through the various verify() methods throughout the
+    library by the user. A convenience method is provided in Document
     for listing all of the errors. Otherwise, a handful of methods
     are available here for interacting with the Verification object
-    directly. 
+    directly.
 
     .. versionadded:: 0.2.0
     """
@@ -50,7 +50,7 @@ class Verification():
         """
         Absorbs an existing verification object in self. This is
         helpful when you have many verification objects that you'd
-        like to aggregate. 
+        like to aggregate.
 
         :param Verification verification: the verification object to absorb
         """
@@ -70,14 +70,19 @@ class InlineText:
     """
     The basic unit of text in markdown. All components which contain
     text are built using this class instead of strings directly. That
-    way, those elements capture all styling information. 
+    way, those elements capture all styling information.
+    
+    .. versionchanged:: 0.12.0
+        Added strike parameter
 
     :param str text: the inline text to render
     :param str url: the link associated with the inline text
-    :param bool bold: the bold state of the inline text; 
+    :param bool bold: the bold state of the inline text;
         set to True to render bold inline text (i.e., True -> **bold**)
-    :param bool italics: the italics state of the inline text; 
+    :param bool italics: the italics state of the inline text;
         set to True to render inline text in italics (i.e., True -> *italics*)
+    :param bool strikethrough: the strikethrough state of the inline text;
+        set to True to render inline text with a strikethrough (i.e., True -> ~~strikethrough~~)
     :param bool code: the italics state of the inline text;
         set to True to render inline text as code (i.e., True -> `code`)
     :param bool image: the image state of the inline text;
@@ -91,6 +96,7 @@ class InlineText:
         url: str = None,
         bold: bool = False,
         italics: bool = False,
+        strikethrough: bool = False,
         code: bool = False,
         image: bool = False
     ) -> None:
@@ -100,6 +106,7 @@ class InlineText:
         self._url = url
         self._code = code
         self._image = image
+        self._strikethrough = strikethrough
 
     def __str__(self) -> str:
         return self.render()
@@ -108,7 +115,7 @@ class InlineText:
         """
         Renders self as a string. In this case,
         inline text can represent many different types of data from
-        stylized text to inline code to links and images. 
+        stylized text to inline code to links and images.
 
         :return: the InlineText object as a string
         """
@@ -117,6 +124,8 @@ class InlineText:
             text = f"**{text}**"
         if self._italics:
             text = f"*{text}*"
+        if self._strikethrough:
+            text = f"~~{text}~~"
         if self._url:
             text = f"[{text}]({self._url})"
         if self._url and self._image:
@@ -159,7 +168,7 @@ class InlineText:
     def is_text(self) -> bool:
         """
         Checks if this InlineText is a text-only element. If not, it must
-        be an image, a URL, or an inline code snippet. 
+        be an image, a URL, or an inline code snippet.
 
         .. versionadded:: 0.2.0
 
@@ -177,7 +186,7 @@ class InlineText:
 
     def bold(self) -> InlineText:
         """
-        Adds bold styling to self. 
+        Adds bold styling to self.
 
         .. versionchanged:: 0.7.0
             Modified to return previous bold state
@@ -189,7 +198,7 @@ class InlineText:
 
     def unbold(self) -> InlineText:
         """
-        Removes bold styling from self. 
+        Removes bold styling from self.
 
         .. versionchanged:: 0.7.0
             Modified to return previous bold state
@@ -212,7 +221,7 @@ class InlineText:
 
     def unitalicize(self) -> InlineText:
         """
-        Removes italics styling from self. 
+        Removes italics styling from self.
 
         .. versionadded:: 0.7.0
 
@@ -220,6 +229,28 @@ class InlineText:
         """
         self._italics = False
         return self
+    
+    def strikethrough(self) -> InlineText:
+        """
+        Adds strikethrough styling to self.
+        
+        .. versionadded:: 0.12.0
+
+        :return: self
+        """
+        self._strikethrough = True
+        return self
+    
+    def unstrikethrough(self) -> InlineText:
+        """
+        Remove strikethrough styling from self.
+        
+        .. versionadded:: 0.12.0
+
+        :return: self
+        """
+        self._strikethrough = False
+        return self
 
     def code(self) -> InlineText:
         """
@@ -268,8 +299,8 @@ class InlineText:
 
     def reset(self) -> InlineText:
         """
-        Removes all settings from self (e.g., bold, code, italics, url, etc.). 
-        All that will remain is the text itself. 
+        Removes all settings from self (e.g., bold, code, italics, url, etc.).
+        All that will remain is the text itself.
 
         .. versionadded:: 0.7.0
 
@@ -284,55 +315,56 @@ class InlineText:
 
 
 class CheckBox(InlineText):
-        """
-        A checkable box, based of InlineText.
-        Supports all formats available via InlineText (eg. url, bold, italics, etc.) 
+    """
+    A checkable box, based of InlineText.
+    Supports all formats available via InlineText (eg. url, bold, italics, etc.)
 
-        :param str text: the inline text to render
-        :param str url: the link associated with the inline text
-        :param bool bold: the bold state of the inline text; 
-            set to True to render bold inline text (i.e., True -> **bold**)
-        :param bool italics: the italics state of the inline text; 
-            set to True to render inline text in italics (i.e., True -> *italics*)
-        :param bool code: the italics state of the inline text;
-            set to True to render inline text as code (i.e., True -> `code`)
-        :param bool image: the image state of the inline text;
-            set to True to render inline text as an image;
-            must include url parameter to render
-        :param bool checked: the checkbox state, checked or not;
-            set to True to render checkbox as checked
-        """
-        def __init__(
-            self,
-            text: str,
-            url: str = None,
-            bold: bool = False,
-            italics: bool = False,
-            code: bool = False,
-            image: bool = False,
-            checked: bool = False
-        ) -> None:
-            super().__init__(
-                    text,
-                    url = url,
-                    bold = bold,
-                    italics = italics,
-                    code = code,
-                    image = image
-                    )
-            self.checked = checked
+    :param str text: the inline text to render
+    :param str url: the link associated with the inline text
+    :param bool bold: the bold state of the inline text;
+        set to True to render bold inline text (i.e., True -> **bold**)
+    :param bool italics: the italics state of the inline text;
+        set to True to render inline text in italics (i.e., True -> *italics*)
+    :param bool code: the italics state of the inline text;
+        set to True to render inline text as code (i.e., True -> `code`)
+    :param bool image: the image state of the inline text;
+        set to True to render inline text as an image;
+        must include url parameter to render
+    :param bool checked: the checkbox state, checked or not;
+        set to True to render checkbox as checked
+    """
 
-        def render(self) -> str:
-            text = super().render()
-            checked_str = "X" if self.checked else " "
-            return f"[{checked_str}] {text}"
+    def __init__(
+        self,
+        text: str,
+        url: str = None,
+        bold: bool = False,
+        italics: bool = False,
+        code: bool = False,
+        image: bool = False,
+        checked: bool = False
+    ) -> None:
+        super().__init__(
+            text,
+            url=url,
+            bold=bold,
+            italics=italics,
+            code=code,
+            image=image
+        )
+        self.checked = checked
+
+    def render(self) -> str:
+        text = super().render()
+        checked_str = "X" if self.checked else " "
+        return f"[{checked_str}] {text}"
 
 
 class Element:
     """
-    An element is defined as a standalone section of a markdown file. 
+    An element is defined as a standalone section of a markdown file.
     All elements are to be surrounded by empty lines. Examples of elements
-    include paragraphs, headers, tables, and lists. 
+    include paragraphs, headers, tables, and lists.
     """
 
     def __init__(self):
@@ -345,7 +377,7 @@ class Element:
         """
         Renders the element as a markdown string.
         This function is called by __str__ for all classes
-        which inherit Element. 
+        which inherit Element.
 
         :raises NotImplementedError: interface method never to be implemented
         :return: the element as a markdown string
@@ -366,7 +398,7 @@ class HorizontalRule(Element):
     """
     A horizontal rule is a line separating different sections of
     a document. Horizontal rules really only come in one form,
-    so there are no settings to adjust. 
+    so there are no settings to adjust.
 
     .. versionadded:: 0.2.0
     """
@@ -401,14 +433,14 @@ class HorizontalRule(Element):
 class Header(Element):
     """
     A header is a text element which serves as the title for a new
-    section of a document. Headers come in six main sizes which 
+    section of a document. Headers come in six main sizes which
     correspond to the six headers sizes in HTML (e.g., <h1>).
 
-    :param Union[InlineText, str] text: the header text
+    :param InlineText | str text: the header text
     :param int level: the header level between 1 and 6 (rounds to closest bound if out of range)
     """
 
-    def __init__(self, text: Union[InlineText, str], level: int) -> None:
+    def __init__(self, text: InlineText | str, level: int) -> None:
         super().__init__()
         self._text: InlineText = self._process_text(text)
         self._level: int = self._process_level(level)
@@ -442,7 +474,7 @@ class Header(Element):
     def render(self) -> str:
         """
         Renders the header in markdown according to
-        the level provided. 
+        the level provided.
 
         :return: the header as a markdown string
         """
@@ -485,7 +517,7 @@ class Paragraph(Element):
     .. versionchanged:: 0.4.0
         Expanded constructor to accept strings directly
 
-    :param Iterable[Union[InlineText, str]] content: a "list" of text objects to render as a paragraph 
+    :param Iterable[InlineText | str] content: a "list" of text objects to render as a paragraph
     :param bool code: the code state of the paragraph;
         set True to convert the paragraph to a code block (i.e., True -> ```code```)
     :param str lang: the language of the code snippet;
@@ -494,7 +526,7 @@ class Paragraph(Element):
         set True to convert the paragraph to a blockquote (i.e., True -> > quote)
     """
 
-    def __init__(self, content: Iterable[Union[InlineText | str]], code: bool = False, lang: str = "generic", quote: bool = False):
+    def __init__(self, content: Iterable[InlineText | str], code: bool = False, lang: str = "generic", quote: bool = False):
         super().__init__()
         self._content: list[InlineText] = self._process_content(content)
         self._code = code
@@ -517,7 +549,7 @@ class Paragraph(Element):
         Renders the paragraph as markdown according to the settings provided.
         For example, if the code flag is enabled, the paragraph will be
         rendered as a code block. If both flags are enabled, code takes
-        precedence. 
+        precedence.
 
         .. versionchanged:: 0.4.0
             No longer assumes spaces between InlineText items
@@ -536,7 +568,7 @@ class Paragraph(Element):
 
     def verify(self) -> Verification:
         """
-        Verifies that the Paragraph is valid. 
+        Verifies that the Paragraph is valid.
 
         .. versionadded:: 0.2.0
 
@@ -555,7 +587,7 @@ class Paragraph(Element):
 
         return verification
 
-    def add(self, text: Union[InlineText, str]) -> None:
+    def add(self, text: InlineText | str) -> None:
         """
         Adds a text object to the paragraph.
 
@@ -571,7 +603,7 @@ class Paragraph(Element):
     def is_text(self) -> bool:
         """
         Checks if this Paragraph is a text-only element. If not, it must
-        be a quote or code block. 
+        be a quote or code block.
 
         .. versionadded:: 0.3.0
 
@@ -585,12 +617,12 @@ class Paragraph(Element):
         InlineText object. This method was created because insert_link and
         replace were literally one line different. This method serves as the
         mediator. Note that using this method will introduce several new
-        underlying InlineText objects even if they could be aggregated. 
+        underlying InlineText objects even if they could be aggregated.
         At some point, we may just expose this method because it seems handy.
         For example, I foresee a need for a function where all the person wants
-        to do is add italics for every instance of a particular string. 
+        to do is add italics for every instance of a particular string.
         Though, I suppose we could include all of that in the default replace
-        method. 
+        method.
 
         :param str target: the target string to replace
         :param InlineText text: the InlineText object to insert in place of the target
@@ -619,7 +651,7 @@ class Paragraph(Element):
         A convenience method which replaces a target string with a string of
         the users choice. Like insert_link, this method is modeled after
         :code:`str.replace()` of the standard library. As a result, a count
-        can be provided to limit the number of strings replaced in the paragraph. 
+        can be provided to limit the number of strings replaced in the paragraph.
 
         .. versionadded:: 0.5.0
 
@@ -637,7 +669,7 @@ class Paragraph(Element):
         is modeled after :code:`str.replace()`, so a count can be
         provided to limit the number of insertions. This method
         will not replace links of text that have already been linked.
-        See replace_link() for that behavior. 
+        See replace_link() for that behavior.
 
         .. code-block:: Python
 
@@ -645,7 +677,7 @@ class Paragraph(Element):
 
         .. versionadded:: 0.2.0
         .. versionchanged:: 0.5.0
-            Changed function to insert links at all instances of target 
+            Changed function to insert links at all instances of target
             rather than just the first instance
 
         :param str target: the string to link
@@ -662,7 +694,7 @@ class Paragraph(Element):
         modeled after :code:`str.replace()`, so a count can be provided to limit
         the number of links replaced in the paragraph. This method is useful
         if you want to replace existing URLs but don't necessarily care what
-        the anchor text is. 
+        the anchor text is.
 
         .. versionadded:: 0.7.0
 
@@ -682,7 +714,7 @@ class Paragraph(Element):
         """
         Verifies all URLs in the paragraph. Results are
         returned in a dictionary where the URLs are
-        mapped to their validity. 
+        mapped to their validity.
 
         :return: a dictionary of URLs mapped to their validity
         """
@@ -699,15 +731,15 @@ class MDList(Element):
     .. versionchanged:: 0.4.0
         Expanded constructor to accept strings directly
 
-    :param Iterable[Union[str, InlineText, Paragraph, MDList]] items: 
+    :param Iterable[str | InlineText | Paragraph | MDList] items:
         a "list" of objects to be rendered as a list
     :param bool ordered: the ordered state of the list;
         set to True to render an ordered list (i.e., True -> 1. item)
     """
 
-    def __init__(self, items: Iterable[Union[str, InlineText, Paragraph, MDList]], ordered: bool = False) -> None:
+    def __init__(self, items: Iterable[str | InlineText | Paragraph | MDList], ordered: bool = False) -> None:
         super().__init__()
-        self._items: Union[MDList, Paragraph] = self._process_items(items)
+        self._items: MDList | Paragraph = self._process_items(items)
         self._ordered = ordered
         self._space = ""
 
@@ -732,7 +764,7 @@ class MDList(Element):
         """
         Returns the number of spaces that any sublists should be indented.
 
-        :param int item_index: the index of the item to check (only used for ordered lists); 
+        :param int item_index: the index of the item to check (only used for ordered lists);
             defaults to -1
         :return: the number of spaces
         """
@@ -746,7 +778,7 @@ class MDList(Element):
         """
         Renders the markdown list according to the settings provided.
         For example, if the the ordered flag is set, an ordered list
-        will be rendered in markdown. 
+        will be rendered in markdown.
 
         :return: the list as a markdown string
         """
@@ -768,7 +800,7 @@ class MDList(Element):
         """
         Verifies that the markdown list is valid. Mainly, this checks the validity
         of the containing InlineText items. The MDList class has no way to
-        instantiate it incorrectly, beyond providing the wrong data types. 
+        instantiate it incorrectly, beyond providing the wrong data types.
 
         .. versionadded:: 0.2.0
 
@@ -785,23 +817,24 @@ class MDList(Element):
 class MDCheckList(MDList):
     """
     A markdown CheckBox list has boxes that can be clicked.
-    
+
     .. versionadded:: 0.10.0
 
-    :param Iterable[Union[str, InlineText, Paragraph, MDList]] items: 
+    :param Iterable[str | InlineText | Paragraph | MDList] items:
         a "list" of objects to be rendered as a Checkbox list
     :param bool checked: the state of the checkbox;
         set to True to render a checked box (i.e., True -> - [x] item)
     """
-    def __init__(self,  items: Iterable[Union[str, InlineText, Paragraph, MDList]], checked: bool=False) -> None:
+
+    def __init__(self,  items: Iterable[str | InlineText | Paragraph | MDList], checked: bool = False) -> None:
         super().__init__(items, False)
         self.checked = checked
-    
+
     def render(self) -> str:
         """
         Renders the markdown Check Box list according to the settings provided.
         For example, if the the checked flag is set, a checked list
-        will be rendered in markdown. 
+        will be rendered in markdown.
 
         :return: the list as a markdown string
         """
@@ -816,22 +849,22 @@ class MDCheckList(MDList):
                 output.append(f"{self._space}- [{checked_str}] {item}")
 
         return "\n".join(output)
-    
+
 
 class TableOfContents(Element):
     """
     A Table of Contents is an element containing an ordered list
-    of all the `<h2>` headers in the document by default. A range can be 
-    specified to customize which headers (e.g., `<h3>`) are included in 
-    the table of contents. This element can be placed anywhere in the document. 
+    of all the `<h2>` headers in the document by default. A range can be
+    specified to customize which headers (e.g., `<h3>`) are included in
+    the table of contents. This element can be placed anywhere in the document.
 
     .. versionadded:: 0.2.0
 
     .. versionchanged:: 0.8.0
        Added optional levels parameter
 
-    :param Document doc: a reference to the document containing this table of contents 
-    :param list[int] levels: a range of integers representing the sequence of header levels 
+    :param Document doc: a reference to the document containing this table of contents
+    :param list[int] levels: a range of integers representing the sequence of header levels
         to include in the table of contents; defaults to range(2, 3)
     """
 
@@ -854,7 +887,7 @@ class TableOfContents(Element):
 
     def _assemble_table_of_contents(self, headers: Iterable, position: int) -> tuple(MDList, int):
         """
-        Assembles the table of contents from the headers in the document. 
+        Assembles the table of contents from the headers in the document.
 
         :return: a list of strings representing the table of contents
         """
@@ -891,7 +924,7 @@ class TableOfContents(Element):
     def verify(self) -> Verification:
         """
         A Table of Contents is generated through a circular reference
-        to the Document it contains. There is no way to instantiate 
+        to the Document it contains. There is no way to instantiate
         this incorrectly.
 
         .. versionadded:: 0.2.0
@@ -904,32 +937,41 @@ class TableOfContents(Element):
 class Table(Element):
     """
     A table is a standalone element of rows and columns. Data is rendered
-    according to underlying InlineText items. 
+    according to underlying InlineText items.
 
     .. versionchanged:: 0.4.0
         Added optional alignment parameter and expanded constructor to accept strings
+    .. versionchanged:: 0.11.0
+        Added optional indentation parameter for the whole table
+    .. versionchanged:: 0.12.0
+        Made body parameter optional
 
     :param header: the header row of labels
     :param body: the collection of rows of data
-    :param align: the column alignment 
+    :param align: the column alignment
+    :param indent: indent size for the whole table
     """
 
     def __init__(
         self,
-        header: Iterable[Union[str, InlineText, Paragraph]],
-        body: Iterable[Iterable[Union[str, InlineText, Paragraph]]],
-        align: Iterable[Align] = None
+        header: Iterable[str | InlineText | Paragraph],
+        body: Iterable[Iterable[str | InlineText | Paragraph]] = [],
+        align: Iterable[Align] = None,
+        indent: int = 0
     ) -> None:
         logger.debug(f"Initializing table\n{(header, body, align)}")
         super().__init__()
-        self._header, self._body, self._widths = self._process_table(
-            header, body)
+        self._header: list[Paragraph]
+        self._body: list[list[Paragraph]]
+        self._widths: list[int]
+        self._header, self._body, self._widths = self._process_table(header, body)
         self._align = align
+        self._indent = indent
 
     class Align(Enum):
         """
         Align is an enum only used by the Table class to specify the alignment
-        of various columns in the table. 
+        of various columns in the table.
 
         .. versionadded:: 0.4.0
         """
@@ -979,10 +1021,18 @@ class Table(Element):
 
         return processed_header, processed_body, widths
 
+    def add_row(self, row: Iterable[str | InlineText | Paragraph]) -> None:
+        """
+        Adds a row to the end of table. 
+
+        .. versionadded:: 0.12.0
+        """
+        self._body.append(row)
+
     def render(self) -> str:
         """
         Renders a markdown table from a header "list"
-        and a data set. 
+        and a data set.
 
         .. versionchanged:: 0.4.0
             Modified to support column alignment and pipes on both sides of the table
@@ -990,16 +1040,18 @@ class Table(Element):
         :return: a table as a markdown string
         """
         rows = list()
-        header = [str(item).ljust(self._widths[i])
-                  for i, item in enumerate(self._header)]
+        header = [
+            str(item).ljust(self._widths[i])
+            for i, item in enumerate(self._header)
+        ]
         body = [
             [str(item).ljust(self._widths[i]) for i, item in enumerate(row)]
             for row in self._body
         ]
-        rows.append(f"| {' | '.join(header)} |")
+        rows.append(f"{' ' * self._indent}| {' | '.join(header)} |")
         if not self._align:
             rows.append(
-                f"| {' | '.join('-' * width for width in self._widths)} |")
+                f"{' ' * self._indent}| {' | '.join('-' * width for width in self._widths)} |")
         else:
             meta = []
             for align, width in zip(self._align, self._widths):
@@ -1009,8 +1061,9 @@ class Table(Element):
                     meta.append(f"{'-' * (width - 1)}:")
                 else:
                     meta.append(f":{'-' * (width - 2)}:")
-            rows.append(f"| {' | '.join(meta)} |")
-        rows.extend((f"| {' | '.join(row)} |" for row in body))
+            rows.append(f"{' ' * self._indent}| {' | '.join(meta)} |")
+        rows.extend(
+            (f"{' ' * self._indent}| {' | '.join(row)} |" for row in body))
         return '\n'.join(rows)
 
     def verify(self):
@@ -1018,8 +1071,8 @@ class Table(Element):
         Verifies the integrity of the markdown table. There are various ways
         a user could instantiate this object improperly. For example, they may
         provide a body with roes that are not all equal width. Likewise, the
-        header may not match the width of the body. InlineText elements may also 
-        be malformed. 
+        header may not match the width of the body. InlineText elements may also
+        be malformed.
 
         .. versionadded:: 0.2.0
 
@@ -1051,11 +1104,11 @@ class Document:
     A document represents a markdown file. Documents store
     a collection of elements which are appended with new lines
     between to generate the markdown document. Document methods
-    are intended to provided convenience when generating a 
+    are intended to provided convenience when generating a
     markdown file. However, the functionality is not exhaustive.
     To get the full range of markdown functionality, you can
     take advantage of the :code:`add_element()` function to provide
-    custom markdown elements. 
+    custom markdown elements.
 
     :param name: the file name of the document without the extension
     """
@@ -1094,16 +1147,16 @@ class Document:
 
     def add_element(self, element: Element) -> Element:
         """
-        A generic function for appending elements to the document. 
+        A generic function for appending elements to the document.
         Use this function when you want a little more control over
-        what the output looks like. 
+        what the output looks like.
 
         .. code-block:: Python
 
             doc.add_element(Header(InlineText("Python is Cool!"), 2))
 
         .. versionchanged:: 0.2.0
-           Returns Element generated by this method instead of None. 
+           Returns Element generated by this method instead of None.
 
         :param Element element: a markdown object (e.g., Table, Header, etc.)
         :return: the Element added to this Document
@@ -1114,7 +1167,7 @@ class Document:
         return element
 
     def add_header(self, text: str, level: int = 1) -> Header:
-        """ 
+        """
         A convenience method which adds a simple header to the document:
 
         .. code-block:: Python
@@ -1122,7 +1175,7 @@ class Document:
             doc.add_header("Welcome to SnakeMD!")
 
         .. versionchanged:: 0.2.0
-           Returns Header generated by this method instead of None. 
+           Returns Header generated by this method instead of None.
 
         :param str text: the text for the header
         :param int level: the level of the header from 1 to 6
@@ -1143,7 +1196,7 @@ class Document:
             doc.add_paragraph("Mitochondria is the powerhouse of the cell.")
 
         .. versionchanged:: 0.2.0
-           Returns Paragraph generated by this method instead of None. 
+           Returns Paragraph generated by this method instead of None.
 
         :param str text: any arbitrary text
         :return: the Paragraph added to this Document
@@ -1155,14 +1208,14 @@ class Document:
 
     def add_ordered_list(self, items: Iterable[str]) -> MDList:
         """
-        A convenience method which adds a simple ordered list to the document: 
+        A convenience method which adds a simple ordered list to the document:
 
         .. code-block:: Python
 
             doc.add_ordered_list(["Goku", "Piccolo", "Vegeta"])
 
         .. versionchanged:: 0.2.0
-           Returns MDList generated by this method instead of None. 
+           Returns MDList generated by this method instead of None.
 
         :param Iterable[str] items: a "list" of strings
         :return: the MDList added to this Document
@@ -1174,14 +1227,14 @@ class Document:
 
     def add_unordered_list(self, items: Iterable[str]) -> MDList:
         """
-        A convenience method which adds a simple unordered list to the document. 
+        A convenience method which adds a simple unordered list to the document.
 
         .. code-block:: Python
 
             doc.add_unordered_list(["Deku", "Bakugo", "Kirishima"])
 
         .. versionchanged:: 0.2.0
-           Returns MDList generated by this method instead of None. 
+           Returns MDList generated by this method instead of None.
 
         :param Iterable[str] items: a "list" of strings
         :return: the MDList added to this Document
@@ -1193,7 +1246,7 @@ class Document:
 
     def add_checklist(self, items: Iterable[str]) -> MDCheckList:
         """
-        A convenience method which adds a simple checklist to the document. 
+        A convenience method which adds a simple checklist to the document.
 
         .. code-block:: Python
 
@@ -1204,7 +1257,8 @@ class Document:
         :param Iterable[str] items: a "list" of strings
         :return: the MDCheckList added to this Document
         """
-        md_checklist = MDCheckList([InlineText(item) for item in items], checked=False)
+        md_checklist = MDCheckList([InlineText(item)
+                                   for item in items], checked=False)
         self._contents.append(md_checklist)
         logger.debug(f"Added checklist to document\n{md_checklist}")
         return md_checklist
@@ -1213,7 +1267,8 @@ class Document:
         self,
         header: Iterable[str],
         data: Iterable[Iterable[str]],
-        align: Iterable[Table.Align] = None
+        align: Iterable[Table.Align] = None,
+        indent: int = 0
     ) -> Table:
         """
         A convenience method which adds a simple table to the document:
@@ -1226,23 +1281,27 @@ class Document:
                     ["1st", "Robert"],
                     ["2nd", "Rae"]
                 ],
-                [Table.Align.CENTER, Table.Align.RIGHT]
+                [Table.Align.CENTER, Table.Align.RIGHT],
+                0
             )
 
         .. versionchanged:: 0.2.0
-            Returns Table generated by this method instead of None. 
+            Returns Table generated by this method instead of None.
         .. versionchanged:: 0.4.0
             Added optional alignment parameter
+        .. versionchanged:: 0.11.0
+            Added optional indentation parameter
 
         :param Iterable[str] header: a "list" of strings
         :param Iterable[Iterable[str]] data: a "list" of "lists" of strings
         :param Iterable[Table.Align] align: a "list" of column alignment values;
             defaults to None
+        :param int indent: indent size for the whole table
         :return: the Table added to this Document
         """
         header = [Paragraph([text]) for text in header]
         data = [[Paragraph([item]) for item in row] for row in data]
-        table = Table(header, data, align)
+        table = Table(header, data, align, indent)
         self._contents.append(table)
         logger.debug(f"Added table to document\n{table}")
         return table
@@ -1276,7 +1335,7 @@ class Document:
             doc.add_quote("Welcome to the Internet!")
 
         .. versionchanged:: 0.2.0
-           Returns Paragraph generated by this method instead of None. 
+           Returns Paragraph generated by this method instead of None.
 
         :param str text: the text to be quoted
         :return: the Paragraph added to this Document
@@ -1309,7 +1368,7 @@ class Document:
         can be called where you want to add a table of contents to your
         document. The table itself is lazy loaded, so it always captures
         all of the header elements regardless of where the table of contents
-        is added to the document. 
+        is added to the document.
 
         .. code-block:: Python
 
@@ -1332,7 +1391,7 @@ class Document:
 
     def scramble(self) -> None:
         """
-        A silly method which mixes all of the elements in this document in 
+        A silly method which mixes all of the elements in this document in
         a random order.
         """
         random.shuffle(self._contents)
@@ -1346,7 +1405,8 @@ class Document:
         :param str encoding: the encoding to use
         """
         pathlib.Path(dump_dir).mkdir(parents=True, exist_ok=True)
-        output_file = open(os.path.join(dump_dir, self._get_file_name()), "w+", encoding=encoding)
+        output_file = open(os.path.join(
+            dump_dir, self._get_file_name()), "w+", encoding=encoding)
         output_file.write(str(self))
         output_file.close()
 
